#include "orbsvcs/Log/LogRecordStore.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_LogRecordStore::TAO_LogRecordStore ()
{
}

TAO_LogRecordStore::~TAO_LogRecordStore ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
